@@ -1,10 +1,11 @@
-sim_monomolecular <- function(N = 10, dt = 1, y0 = 0.01, r, n, alpha = 0.2) {
+sim_monomolecular <- function(N = 10, dt = 1, y0 = 0.01, r, n, alpha = 0.2){
   time <- seq(0, N, by = dt)
   w <- numeric(length(time))
   y <- numeric(length(time))
   y[1] <- y0
   aa <- -1
   bb <- 1
+
   for (k in 1:(length(time) - 1)) {
     r[k + 1] <- r[k]
 
@@ -26,7 +27,8 @@ sim_monomolecular <- function(N = 10, dt = 1, y0 = 0.01, r, n, alpha = 0.2) {
       if (w[i] > 1) {
         w[i] <- 0.999
       }
-      if (w [i] < y0) {
+
+      if (w[i] < y0) {
         w[i] <- y0
       }
     }
@@ -39,5 +41,7 @@ sim_monomolecular <- function(N = 10, dt = 1, y0 = 0.01, r, n, alpha = 0.2) {
     colnames(data_all) <- c("replicates", "time", "y", "random_y")
   }
 
-  return(data.frame(data_all))
+  data_all = data.frame(data_all)
+  return(data_all)
+
 }
